Package: mlr3misc
Title: Helper Functions for 'mlr3'
Version: 0.15.1
Authors@R: c(
    person("Michel", "Lang", , "michellang@gmail.com", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0001-9754-0393")),
    person("Patrick", "Schratz", , "patrick.schratz@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0003-0748-6624"))
  )
Description: Frequently used helper functions and assertions used in
    'mlr3' and its companion packages. Comes with helper functions for
    functional programming, for printing, to work with 'data.table', as
    well as some generally useful 'R6' classes. This package also
    supersedes the package 'BBmisc'.
License: LGPL-3
URL: https://mlr3misc.mlr-org.com, https://github.com/mlr-org/mlr3misc
BugReports: https://github.com/mlr-org/mlr3misc/issues
Depends: R (>= 3.1.0)
Imports: backports (>= 0.1.5), checkmate, data.table, digest, methods,
        R6
Suggests: callr, evaluate, paradox, testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
NeedsCompilation: yes
RoxygenNote: 7.3.1
Collate: 'Dictionary.R' 'named_list.R' 'Callback.R' 'Context.R'
        'as_factor.R' 'as_short_string.R' 'assert_ro_binding.R'
        'calculate_hash.R' 'capitalize.R' 'catn.R'
        'check_packages_installed.R' 'chunk.R' 'compose.R'
        'compute_mode.R' 'count_missing.R' 'crate.R' 'cross_join.R'
        'dictionary_sugar.R' 'dictionary_sugar_safe.R' 'did_you_mean.R'
        'distinct_values.R' 'encapsulate.R' 'enframe.R'
        'extract_vars.R' 'format_bib.R' 'formulate.R' 'get_private.R'
        'get_seed.R' 'has_element.R' 'ids.R' 'insert_named.R'
        'invoke.R' 'is_scalar_na.R' 'keep_in_bounds.R' 'leanify.R'
        'load_dataset.R' 'map_values.R' 'modify.R' 'named_vector.R'
        'names2.R' 'nin.R' 'open_help.R' 'printf.R' 'probe.R'
        'purrr_map.R' 'rcbind.R' 'rd_info.R' 'recycle_vector.R'
        'register_namespace_callback.R' 'remove_named.R'
        'reorder_vector.R' 'require_namespaces.R' 'rowwise_table.R'
        'seq.R' 'set_class.R' 'set_names.R' 'set_params.R' 'shuffle.R'
        'str_collapse.R' 'str_indent.R' 'str_trunc.R' 'strip_srcrefs.R'
        'to_decimal.R' 'topo_sort.R' 'transpose.R' 'unnest.R'
        'which_max.R' 'with_package.R' 'zzz.R'
Packaged: 2024-06-24 19:04:08 UTC; marc
Author: Michel Lang [cre, aut] (<https://orcid.org/0000-0001-9754-0393>),
  Patrick Schratz [aut] (<https://orcid.org/0000-0003-0748-6624>)
Maintainer: Michel Lang <michellang@gmail.com>
Repository: CRAN
Date/Publication: 2024-06-24 21:00:01 UTC
Built: R 4.4.2; aarch64-apple-darwin24.3.0; 2025-02-25 07:43:59 UTC; unix
