Package: mlr3misc
Title: Helper Functions for 'mlr3'
Version: 0.8.0
Authors@R: 
    c(person(given = "Michel",
             family = "Lang",
             role = c("cre", "aut"),
             email = "michellang@gmail.com",
             comment = c(ORCID = "0000-0001-9754-0393")),
      person(given = "Patrick",
             family = "Schratz",
             role = "aut",
             email = "patrick.schratz@gmail.com",
             comment = c(ORCID = "0000-0003-0748-6624")))
Description: Frequently used helper functions and assertions
    used in 'mlr3' and its companion packages. Comes with helper functions
    for functional programming, for printing, to work with 'data.table',
    as well as some generally useful 'R6' classes. This package also
    supersedes the package 'BBmisc'.
License: LGPL-3
URL: https://mlr3misc.mlr-org.com, https://github.com/mlr-org/mlr3misc
BugReports: https://github.com/mlr-org/mlr3misc/issues
Depends: R (>= 3.1.0)
Imports: backports (>= 0.1.5), checkmate, data.table, R6
Suggests: callr, evaluate, paradox, testthat (>= 3.0.0)
Encoding: UTF-8
NeedsCompilation: yes
Config/testthat/edition: 3
Config/testthat/parallel: true
RoxygenNote: 7.1.1
Packaged: 2021-03-19 12:09:39 UTC; lang
Author: Michel Lang [cre, aut] (<https://orcid.org/0000-0001-9754-0393>),
  Patrick Schratz [aut] (<https://orcid.org/0000-0003-0748-6624>)
Maintainer: Michel Lang <michellang@gmail.com>
Repository: CRAN
Date/Publication: 2021-03-19 12:40:02 UTC
Built: R 3.6.3; x86_64-w64-mingw32; 2021-03-19 15:02:46 UTC; windows
Archs: x64
