# Generated by roxygen2: do not edit by hand

S3method(as.data.table,Dictionary)
S3method(discard,data.frame)
S3method(discard,data.table)
S3method(discard,default)
S3method(distinct_values,default)
S3method(distinct_values,factor)
S3method(distinct_values,logical)
S3method(insert_named,data.frame)
S3method(insert_named,data.table)
S3method(insert_named,default)
S3method(insert_named,environment)
S3method(keep,data.frame)
S3method(keep,data.table)
S3method(keep,default)
S3method(map_at,data.table)
S3method(map_at,default)
S3method(map_if,data.frame)
S3method(map_if,data.table)
S3method(map_if,default)
S3method(modify_at,data.table)
S3method(modify_at,default)
S3method(modify_if,data.table)
S3method(modify_if,default)
S3method(remove_named,data.frame)
S3method(remove_named,data.table)
S3method(remove_named,default)
S3method(remove_named,environment)
export("%nin%")
export(Dictionary)
export(as_factor)
export(as_short_string)
export(assert_ro_binding)
export(calculate_hash)
export(capitalize)
export(catf)
export(check_packages_installed)
export(chunk)
export(chunk_vector)
export(cite_bib)
export(compose)
export(compute_mode)
export(count_missing)
export(crate)
export(cross_join)
export(deframe)
export(detect)
export(dictionary_sugar)
export(dictionary_sugar_get)
export(dictionary_sugar_mget)
export(did_you_mean)
export(discard)
export(distinct_values)
export(encapsulate)
export(enframe)
export(every)
export(extract_vars)
export(format_bib)
export(formulate)
export(get_seed)
export(has_element)
export(ids)
export(imap)
export(imap_chr)
export(imap_dbl)
export(imap_dtc)
export(imap_dtr)
export(imap_int)
export(imap_lgl)
export(insert_named)
export(invoke)
export(is_scalar_na)
export(keep)
export(keep_in_bounds)
export(leanify_package)
export(leanify_r6)
export(load_dataset)
export(map)
export(map_at)
export(map_chr)
export(map_dbl)
export(map_dtc)
export(map_dtr)
export(map_if)
export(map_int)
export(map_lgl)
export(map_values)
export(messagef)
export(modify_at)
export(modify_if)
export(named_list)
export(named_vector)
export(names2)
export(open_help)
export(pmap)
export(pmap_chr)
export(pmap_dbl)
export(pmap_dtc)
export(pmap_dtr)
export(pmap_int)
export(pmap_lgl)
export(rcbind)
export(rd_format_packages)
export(rd_format_range)
export(rd_format_string)
export(rd_info)
export(register_namespace_callback)
export(remove_named)
export(reorder_vector)
export(require_namespaces)
export(rowwise_table)
export(seq_along0)
export(seq_col)
export(seq_len0)
export(seq_row)
export(set_class)
export(set_col_names)
export(set_names)
export(shuffle)
export(some)
export(stopf)
export(str_collapse)
export(str_indent)
export(str_trunc)
export(to_decimal)
export(topo_sort)
export(transpose_list)
export(unnest)
export(warningf)
export(which_max)
export(which_min)
export(with_package)
import(checkmate)
import(data.table)
importFrom(R6,R6Class)
importFrom(R6,is.R6)
importFrom(digest,digest)
importFrom(stats,as.formula)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(utils,adist)
importFrom(utils,head)
importFrom(utils,tail)
useDynLib(mlr3misc,c_count_missing)
useDynLib(mlr3misc,c_keep_in_bounds)
useDynLib(mlr3misc,c_to_decimal)
useDynLib(mlr3misc,c_which_max)
